@@ -21,6 +21,7 @@ from .onnx import onnx_operator  # noqa: E402
 from .onnx import array_feature_extractor as onnx_afe  # noqa: E402, F811
 from .onnx import binarizer as onnx_binarizer  # noqa: E402, F811
 from .onnx import feature_vectorizer  # noqa: E402
+from .onnx import imputer as onnx_imputer  # noqa: E402
 from .onnx import label_encoder as onnx_label_encoder  # noqa: E402, F811
 from .onnx import linear as onnx_linear  # noqa: E402, F811
 from .onnx import normalizer as onnx_normalizer  # noqa: E402, F811
@@ -29,6 +30,8 @@ from .onnx import scaler as onnx_scaler  # noqa: E402, F811
 from .onnx import sv as onnx_sv  # noqa: E402, F811
 from .onnx import tree_ensemble  # noqa: E402
 from .sklearn import array_feature_extractor as sklearn_afe  # noqa: E402
+from .sklearn import bagging  # noqa: E402
+from .sklearn import cluster  # noqa: E402
 from .sklearn import decision_tree  # noqa: E402
 from .sklearn import decomposition  # noqa: E402
 from .sklearn import discretizer as sklearn_discretizer  # noqa: E402
