@@ -65,14 +65,15 @@ def convert_sklearn_lgbm_classifier(operator, device, extra_config):
     Returns:
         A PyTorch model
     """
-    assert operator is not None
+    assert operator is not None, "Cannot convert None operator"
 
-    # Get tree information out of the model.
     n_features = operator.raw_operator._n_features
     tree_infos = operator.raw_operator.booster_.dump_model()["tree_info"]
     n_classes = operator.raw_operator._n_classes
 
-    return convert_gbdt_classifier_common(tree_infos, _get_tree_parameters, n_features, n_classes, extra_config=extra_config)
+    return convert_gbdt_classifier_common(
+        operator, tree_infos, _get_tree_parameters, n_features, n_classes, extra_config=extra_config
+    )
 
 
 def convert_sklearn_lgbm_regressor(operator, device, extra_config):
@@ -87,7 +88,7 @@ def convert_sklearn_lgbm_regressor(operator, device, extra_config):
     Returns:
         A PyTorch model
     """
-    assert operator is not None
+    assert operator is not None, "Cannot convert None operator"
 
     # Get tree information out of the model.
     n_features = operator.raw_operator._n_features
@@ -95,7 +96,7 @@ def convert_sklearn_lgbm_regressor(operator, device, extra_config):
     if operator.raw_operator._objective == "tweedie":
         extra_config[constants.POST_TRANSFORM] = constants.TWEEDIE
 
-    return convert_gbdt_common(tree_infos, _get_tree_parameters, n_features, extra_config=extra_config)
+    return convert_gbdt_common(operator, tree_infos, _get_tree_parameters, n_features, extra_config=extra_config)
 
 
 # Register the converters.
