@@ -47,7 +47,7 @@ def _get_tree_infos_from_onnx_ml_operator(model):
         elif attr.name == "nodes_treeids":
             tree_ids = attr.ints
         elif attr.name == "classlabels_int64s":
-            classes = attr.ints
+            classes = list(attr.ints)
         elif attr.name == "classlabels_strings ":
             if len(attr.strings) > 0:
                 raise AssertionError("String class labels not supported yet.")
@@ -116,12 +116,13 @@ def _get_tree_infos_from_onnx_ml_operator(model):
                         l_count += 1
             if t_values.shape[0] == 1:
                 # Model creating trees with just a single leaf node. We fix the values here.
-                n_classes = t_values.shape[1]
+                n_classes = t_values.shape[1] if len(t_values.shape) > 1 else 1
                 t_values = np.array([np.array([0.0]), t_values[0], t_values[0]])
                 t_values.reshape(3, n_classes)
             if is_decision_tree and n_classes == 2:  # We need to fix the probabilities in this case.
+                max_tree_ids = max(tree_ids) + 1
                 for k in range(len(t_left)):
-                    prob = (1 / (max(tree_ids) + 1)) - t_values[k][1]
+                    prob = (1 / max_tree_ids) - t_values[k][1]
                     t_values[k][0] = prob
 
             tree_infos.append(
@@ -153,7 +154,7 @@ def _get_tree_infos_from_onnx_ml_operator(model):
                 l_count += 1
     if t_values.shape[0] == 1:
         # Model creating trees with just a single leaf node. We fix the values here.
-        n_classes = t_values.shape[1]
+        n_classes = t_values.shape[1] if len(t_values.shape) > 1 else 1
         t_values = np.array([np.array([0.0]), t_values[0], t_values[0]])
         t_values.reshape(3, n_classes)
     if is_decision_tree and n_classes == 2:  # We need to fix the probabilities in this case.
@@ -200,7 +201,7 @@ def convert_onnx_tree_ensemble_classifier(operator, device=None, extra_config={}
     Returns:
         A PyTorch model
     """
-    assert operator is not None
+    assert operator is not None, "Cannot convert None operator"
 
     # Get tree informations from the operator.
     n_features, tree_infos, classes, post_transform = _get_tree_infos_from_tree_ensemble(
@@ -210,10 +211,12 @@ def convert_onnx_tree_ensemble_classifier(operator, device=None, extra_config={}
     # Generate the model.
     if post_transform == "NONE":
         return convert_decision_ensemble_tree_common(
-            tree_infos, _dummy_get_parameter, get_parameters_for_tree_trav_common, n_features, classes, extra_config
+            operator, tree_infos, _dummy_get_parameter, get_parameters_for_tree_trav_common, n_features, classes, extra_config
         )
     extra_config[constants.POST_TRANSFORM] = post_transform
-    return convert_gbdt_classifier_common(tree_infos, _dummy_get_parameter, n_features, len(classes), classes, extra_config)
+    return convert_gbdt_classifier_common(
+        operator, tree_infos, _dummy_get_parameter, n_features, len(classes), classes, extra_config
+    )
 
 
 def convert_onnx_tree_ensemble_regressor(operator, device=None, extra_config={}):
@@ -228,13 +231,13 @@ def convert_onnx_tree_ensemble_regressor(operator, device=None, extra_config={})
     Returns:
         A PyTorch model
     """
-    assert operator is not None
+    assert operator is not None, "Cannot convert None operator"
 
     # Get tree informations from the operator.
     n_features, tree_infos, _, _ = _get_tree_infos_from_tree_ensemble(operator.raw_operator, device, extra_config)
 
     # Generate the model.
-    return convert_gbdt_common(tree_infos, _dummy_get_parameter, n_features, extra_config=extra_config)
+    return convert_gbdt_common(operator, tree_infos, _dummy_get_parameter, n_features, extra_config=extra_config)
 
 
 register_converter("ONNXMLTreeEnsembleClassifier", convert_onnx_tree_ensemble_classifier)
