@@ -32,6 +32,15 @@ def convert_sklearn_linear_model(operator, device, extra_config):
 
     supported_loss = {"log", "modified_huber", "squared_hinge"}
     classes = [0] if not hasattr(operator.raw_operator, "classes_") else operator.raw_operator.classes_
+    # There is a bug in torch < 1.7.0 that causes a mismatch. See Issue #10
+    if len(classes) > 2:
+        from distutils.version import LooseVersion
+        import torch
+
+        if LooseVersion(torch.__version__) < LooseVersion("1.7.0"):
+            import warnings
+
+            warnings.warn("torch < 1.7.0 may give a mismatch on multiclass. See issue #10.")
 
     if not all(["int" in str(type(x)) for x in classes]):
         raise RuntimeError(
@@ -63,10 +72,11 @@ def convert_sklearn_linear_model(operator, device, extra_config):
 
 def convert_sklearn_linear_regression_model(operator, device, extra_config):
     """
-    Converter for `sklearn.linear_model.LinearRegression`
+    Converter for `sklearn.linear_model.LinearRegression`, `sklearn.svm.LinearSVR` and `sklearn.linear_model.RidgeCV`
 
     Args:
-        operator: An operator wrapping a `sklearn.linear_model.LinearRegression` model
+        operator: An operator wrapping a `sklearn.linear_model.LinearRegression`, `sklearn.svm.LinearSVR`
+            or `sklearn.linear_model.RidgeCV` model
         device: String defining the type of device the converted operator should be run on
         extra_config: Extra configuration used to select the best conversion strategy
 
@@ -86,5 +96,7 @@ def convert_sklearn_linear_regression_model(operator, device, extra_config):
 register_converter("SklearnLinearRegression", convert_sklearn_linear_regression_model)
 register_converter("SklearnLogisticRegression", convert_sklearn_linear_model)
 register_converter("SklearnLinearSVC", convert_sklearn_linear_model)
+register_converter("SklearnLinearSVR", convert_sklearn_linear_regression_model)
 register_converter("SklearnSGDClassifier", convert_sklearn_linear_model)
 register_converter("SklearnLogisticRegressionCV", convert_sklearn_linear_model)
+register_converter("SklearnRidgeCV", convert_sklearn_linear_regression_model)
