@@ -24,19 +24,24 @@ FastICA,
 GaussianNB,
 GradientBoostingClassifier,
 GradientBoostingRegressor,
+GridSearchCV,
 HistGradientBoostingClassifier,
 HistGradientBoostingRegressor,
 IsolationForest,
 KernelPCA,
 KBinsDiscretizer,
+KMeans,
 KNeighborsClassifier,
 KNeighborsRegressor,
 LabelEncoder,
 LinearRegression,
 LinearSVC,
+LinearSVR,
 LogisticRegression,
 LogisticRegressionCV,
+RidgeCV,
 MaxAbsScaler,
+MeanShift,
 MinMaxScaler,
 MissingIndicator,
 MLPClassifier,
@@ -48,6 +53,7 @@ PCA,
 PolynomialFeatures,
 RandomForestClassifier,
 RandomForestRegressor,
+RandomizedGridSearchCV,
 RobustScaler,
 SelectKBest,
 SelectPercentile,
@@ -77,6 +83,7 @@ Binarizer,
 Cast,
 Concat,
 Div,
+Imputer,
 LabelEncoder,
 Less,
 LinearClassifier,
@@ -130,15 +137,10 @@ def _build_sklearn_operator_list():
         from sklearn.tree import DecisionTreeClassifier, DecisionTreeRegressor
 
         # Linear-based models
-        from sklearn.linear_model import (
-            LinearRegression,
-            LogisticRegression,
-            LogisticRegressionCV,
-            SGDClassifier,
-        )
+        from sklearn.linear_model import LinearRegression, LogisticRegression, LogisticRegressionCV, SGDClassifier, RidgeCV
 
         # SVM-based models
-        from sklearn.svm import LinearSVC, SVC, NuSVC
+        from sklearn.svm import LinearSVC, SVC, NuSVC, LinearSVR
 
         # Imputers
         from sklearn.impute import MissingIndicator, SimpleImputer
@@ -156,6 +158,12 @@ def _build_sklearn_operator_list():
         from sklearn.neighbors import KNeighborsClassifier
         from sklearn.neighbors import KNeighborsRegressor
 
+        # Clustering models
+        from sklearn.cluster import KMeans, MeanShift
+
+        # Model selection
+        from sklearn.model_selection import GridSearchCV, RandomizedSearchCV
+
         # Preprocessing
         from sklearn.preprocessing import (
             Binarizer,
@@ -196,9 +204,14 @@ def _build_sklearn_operator_list():
             # Linear-methods
             LinearRegression,
             LinearSVC,
+            LinearSVR,
             LogisticRegression,
             LogisticRegressionCV,
             SGDClassifier,
+            RidgeCV,
+            # Clustering
+            KMeans,
+            MeanShift,
             # Other models
             BernoulliNB,
             GaussianNB,
@@ -313,6 +326,7 @@ def _build_onnxml_operator_list():
             "ArrayFeatureExtractor",
             "Binarizer",
             "FeatureVectorizer",
+            "Imputer",
             "LabelEncoder",
             "OneHotEncoder",
             "Normalizer",
@@ -363,6 +377,7 @@ def _build_sklearn_api_operator_name_map():
         "ArrayFeatureExtractor",
         "Concat",
         "Multiply",
+        "Bagging",
     ]
 
     return {
@@ -452,7 +467,7 @@ backends = _build_backend_map()
 # Supported configurations settings accepted by Hummingbird are defined below.
 # Please check `test.test_extra_conf.py` for examples on how to use these.
 TREE_IMPLEMENTATION = "tree_implementation"
-"""Which tree implementation to use. Values can be: gemm, tree-trav, perf_tree_trav."""
+"""Which tree implementation to use. Values can be: gemm, tree_trav, perf_tree_trav."""
 
 ONNX_OUTPUT_MODEL_NAME = "onnx_model_name"
 """For ONNX models we can set the name of the output model."""
